from .utils.enum import LengthType
from .utils.parser import parseString, parseBytesToBin, parseDE048, parseDE112, parsePds, parseBin
from .utils.parser import unparseString, unparseBytesToBin, unparseDE048, unparseDE112, unparsePds, unparseBin


mastercard = {"1987": {
    "MTI": {"type": LengthType.FIXED, "limit": 4, "parser": parseString, "unparser": unparseString},
    "DE000": {"type": LengthType.FIXED, "limit": 8, "parser": parseBytesToBin, "unparser": unparseBytesToBin},
    "DE001": {"type": LengthType.FIXED, "limit": 8, "parser": parseBytesToBin, "unparser": unparseBytesToBin},
    "DE002": {"type": LengthType.LLVAR, "limit": 19, "parser": parseString, "unparser": unparseString},
    "DE003": {"type": LengthType.FIXED, "limit": 6, "parser": parseString, "unparser": unparseString},
    "DE004": {"type": LengthType.FIXED, "limit": 12, "parser": parseString, "unparser": unparseString},
    "DE005": {"type": LengthType.FIXED, "limit": 12, "parser": parseString, "unparser": unparseString},
    "DE006": {"type": LengthType.FIXED, "limit": 12, "parser": parseString, "unparser": unparseString},
    "DE007": {"type": LengthType.FIXED, "limit": 10, "parser": parseString, "unparser": unparseString},
    "DE008": {"type": LengthType.FIXED, "limit": 8, "parser": parseString, "unparser": unparseString},
    "DE009": {"type": LengthType.FIXED, "limit": 8, "parser": parseString, "unparser": unparseString},
    "DE010": {"type": LengthType.FIXED, "limit": 8, "parser": parseString, "unparser": unparseString},
    "DE011": {"type": LengthType.FIXED, "limit": 6, "parser": parseString, "unparser": unparseString},
    "DE012": {"type": LengthType.FIXED, "limit": 6, "parser": parseString, "unparser": unparseString},
    "DE013": {"type": LengthType.FIXED, "limit": 4, "parser": parseString, "unparser": unparseString},
    "DE014": {"type": LengthType.FIXED, "limit": 4, "parser": parseString, "unparser": unparseString},
    "DE015": {"type": LengthType.FIXED, "limit": 4, "parser": parseString, "unparser": unparseString},
    "DE016": {"type": LengthType.FIXED, "limit": 4, "parser": parseString, "unparser": unparseString},
    "DE017": {"type": LengthType.FIXED, "limit": 4, "parser": parseString, "unparser": unparseString},
    "DE018": {"type": LengthType.FIXED, "limit": 4, "parser": parseString, "unparser": unparseString},
    "DE019": {"type": LengthType.FIXED, "limit": 3, "parser": parseString, "unparser": unparseString},
    "DE020": {"type": LengthType.FIXED, "limit": 3, "parser": parseString, "unparser": unparseString},
    "DE021": {"type": LengthType.FIXED, "limit": 3, "parser": parseString, "unparser": unparseString},
    "DE022": {"type": LengthType.FIXED, "limit": 3, "parser": parseString, "unparser": unparseString},
    "DE023": {"type": LengthType.FIXED, "limit": 3, "parser": parseString, "unparser": unparseString},
    "DE024": {"type": LengthType.FIXED, "limit": 3, "parser": parseString, "unparser": unparseString},
    "DE025": {"type": LengthType.FIXED, "limit": 2, "parser": parseString, "unparser": unparseString},
    "DE026": {"type": LengthType.FIXED, "limit": 2, "parser": parseString, "unparser": unparseString},
    "DE027": {"type": LengthType.FIXED, "limit": 1, "parser": parseString, "unparser": unparseString},
    "DE028": {"type": LengthType.FIXED, "limit": 9, "parser": parseString, "unparser": unparseString},
    "DE029": {"type": LengthType.FIXED, "limit": 9, "parser": parseString, "unparser": unparseString},
    "DE030": {"type": LengthType.FIXED, "limit": 9, "parser": parseString, "unparser": unparseString},
    "DE031": {"type": LengthType.FIXED, "limit": 9, "parser": parseString, "unparser": unparseString},
    "DE032": {"type": LengthType.LLVAR, "limit": 11, "parser": parseString, "unparser": unparseString},
    "DE033": {"type": LengthType.LLVAR, "limit": 11, "parser": parseString, "unparser": unparseString},
    "DE034": {"type": LengthType.LLVAR, "limit": 28, "parser": parseString, "unparser": unparseString},
    "DE035": {"type": LengthType.LLVAR, "limit": 37, "parser": parseString, "unparser": unparseString},
    "DE036": {"type": LengthType.LLLVAR, "limit": 104, "parser": parseString, "unparser": unparseString},
    "DE037": {"type": LengthType.FIXED, "limit": 12, "parser": parseString, "unparser": unparseString},
    "DE038": {"type": LengthType.FIXED, "limit": 6, "parser": parseString, "unparser": unparseString},
    "DE039": {"type": LengthType.FIXED, "limit": 2, "parser": parseString, "unparser": unparseString},
    "DE040": {"type": LengthType.FIXED, "limit": 3, "parser": parseString, "unparser": unparseString},
    "DE041": {"type": LengthType.FIXED, "limit": 8, "parser": parseString, "unparser": unparseString},
    "DE042": {"type": LengthType.FIXED, "limit": 15, "parser": parseString, "unparser": unparseString},
    "DE043": {"type": LengthType.FIXED, "limit": 40, "parser": parseString, "unparser": unparseString},
    "DE044": {"type": LengthType.LLVAR, "limit": 25, "parser": parseString, "unparser": unparseString},
    "DE045": {"type": LengthType.LLVAR, "limit": 76, "parser": parseString, "unparser": unparseString},
    "DE046": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE047": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE048": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseDE048, "unparser": unparseDE048},
    "DE049": {"type": LengthType.FIXED, "limit": 3, "parser": parseString, "unparser": unparseString},
    "DE050": {"type": LengthType.FIXED, "limit": 3, "parser": parseString, "unparser": unparseString},
    "DE051": {"type": LengthType.FIXED, "limit": 3, "parser": parseString, "unparser": unparseString},
    "DE052": {"type": LengthType.FIXED, "limit": 8, "parser": parseBytesToBin, "unparser": unparseBytesToBin},
    "DE053": {"type": LengthType.FIXED, "limit": 16, "parser": parseString, "unparser": unparseString},
    "DE054": {"type": LengthType.LLLVAR, "limit": 120, "parser": parseString, "unparser": unparseString},
    "DE055": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseBin, "unparser": unparseBin},
    "DE056": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE057": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE058": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE059": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE060": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE061": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE062": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE063": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE064": {"type": LengthType.FIXED, "limit": 8, "parser": parseBytesToBin, "unparser": unparseBytesToBin},
    "DE065": {"type": LengthType.FIXED, "limit": 8, "parser": parseBytesToBin, "unparser": unparseBytesToBin},
    "DE066": {"type": LengthType.FIXED, "limit": 1, "parser": parseString, "unparser": unparseString},
    "DE067": {"type": LengthType.FIXED, "limit": 2, "parser": parseString, "unparser": unparseString},
    "DE068": {"type": LengthType.FIXED, "limit": 3, "parser": parseString, "unparser": unparseString},
    "DE069": {"type": LengthType.FIXED, "limit": 3, "parser": parseString, "unparser": unparseString},
    "DE070": {"type": LengthType.FIXED, "limit": 3, "parser": parseString, "unparser": unparseString},
    "DE071": {"type": LengthType.FIXED, "limit": 4, "parser": parseString, "unparser": unparseString},
    "DE072": {"type": LengthType.FIXED, "limit": 4, "parser": parseString, "unparser": unparseString},
    "DE073": {"type": LengthType.FIXED, "limit": 6, "parser": parseString, "unparser": unparseString},
    "DE074": {"type": LengthType.FIXED, "limit": 10, "parser": parseString, "unparser": unparseString},
    "DE075": {"type": LengthType.FIXED, "limit": 10, "parser": parseString, "unparser": unparseString},
    "DE076": {"type": LengthType.FIXED, "limit": 10, "parser": parseString, "unparser": unparseString},
    "DE077": {"type": LengthType.FIXED, "limit": 10, "parser": parseString, "unparser": unparseString},
    "DE078": {"type": LengthType.FIXED, "limit": 10, "parser": parseString, "unparser": unparseString},
    "DE079": {"type": LengthType.FIXED, "limit": 10, "parser": parseString, "unparser": unparseString},
    "DE080": {"type": LengthType.FIXED, "limit": 10, "parser": parseString, "unparser": unparseString},
    "DE081": {"type": LengthType.FIXED, "limit": 10, "parser": parseString, "unparser": unparseString},
    "DE082": {"type": LengthType.FIXED, "limit": 12, "parser": parseString, "unparser": unparseString},
    "DE083": {"type": LengthType.FIXED, "limit": 12, "parser": parseString, "unparser": unparseString},
    "DE084": {"type": LengthType.FIXED, "limit": 12, "parser": parseString, "unparser": unparseString},
    "DE085": {"type": LengthType.FIXED, "limit": 12, "parser": parseString, "unparser": unparseString},
    "DE086": {"type": LengthType.FIXED, "limit": 16, "parser": parseString, "unparser": unparseString},
    "DE087": {"type": LengthType.FIXED, "limit": 16, "parser": parseString, "unparser": unparseString},
    "DE088": {"type": LengthType.FIXED, "limit": 16, "parser": parseString, "unparser": unparseString},
    "DE089": {"type": LengthType.FIXED, "limit": 16, "parser": parseString, "unparser": unparseString},
    "DE090": {"type": LengthType.FIXED, "limit": 42, "parser": parseString, "unparser": unparseString},
    "DE091": {"type": LengthType.FIXED, "limit": 1, "parser": parseString, "unparser": unparseString},
    "DE092": {"type": LengthType.FIXED, "limit": 2, "parser": parseString, "unparser": unparseString},
    "DE093": {"type": LengthType.FIXED, "limit": 5, "parser": parseString, "unparser": unparseString},
    "DE094": {"type": LengthType.FIXED, "limit": 7, "parser": parseString, "unparser": unparseString},
    "DE095": {"type": LengthType.FIXED, "limit": 42, "parser": parseString, "unparser": unparseString},
    "DE096": {"type": LengthType.FIXED, "limit": 8, "parser": parseString, "unparser": unparseString},
    "DE097": {"type": LengthType.FIXED, "limit": 17, "parser": parseString, "unparser": unparseString},
    "DE098": {"type": LengthType.FIXED, "limit": 25, "parser": parseString, "unparser": unparseString},
    "DE099": {"type": LengthType.LLVAR, "limit": 11, "parser": parseString, "unparser": unparseString},
    "DE100": {"type": LengthType.LLVAR, "limit": 11, "parser": parseString, "unparser": unparseString},
    "DE101": {"type": LengthType.LLVAR, "limit": 17, "parser": parseString, "unparser": unparseString},
    "DE102": {"type": LengthType.LLVAR, "limit": 28, "parser": parseString, "unparser": unparseString},
    "DE103": {"type": LengthType.LLVAR, "limit": 28, "parser": parseString, "unparser": unparseString},
    "DE104": {"type": LengthType.LLLVAR, "limit": 100, "parser": parseString, "unparser": unparseString},
    "DE105": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE106": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE107": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE108": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE109": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE110": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE111": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE112": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseDE112, "unparser": unparseDE112},
    "DE113": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE114": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE115": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE116": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE117": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE118": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE119": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE120": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE121": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE122": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE123": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE124": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE125": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE126": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE127": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE128": {"type": LengthType.FIXED, "limit": 8, "parser": parseBytesToBin, "unparser": unparseBytesToBin},
}, "1993": {
    "MTI": {"type": LengthType.FIXED, "limit": 4, "parser": parseString, "unparser": unparseString},
    "DE000": {"type": LengthType.FIXED, "limit": 8, "parser": parseBytesToBin, "unparser": unparseBytesToBin},
    "DE001": {"type": LengthType.FIXED, "limit": 8, "parser": parseBytesToBin, "unparser": unparseBytesToBin},
    "DE002": {"type": LengthType.LLVAR, "limit": 19, "parser": parseString, "unparser": unparseString},
    "DE003": {"type": LengthType.FIXED, "limit": 6, "parser": parseString, "unparser": unparseString},
    "DE004": {"type": LengthType.FIXED, "limit": 12, "parser": parseString, "unparser": unparseString},
    "DE005": {"type": LengthType.FIXED, "limit": 12, "parser": parseString, "unparser": unparseString},
    "DE006": {"type": LengthType.FIXED, "limit": 12, "parser": parseString, "unparser": unparseString},
    "DE007": {"type": LengthType.FIXED, "limit": 10, "parser": parseString, "unparser": unparseString},
    "DE008": {"type": LengthType.FIXED, "limit": 8, "parser": parseString, "unparser": unparseString},
    "DE009": {"type": LengthType.FIXED, "limit": 8, "parser": parseString, "unparser": unparseString},
    "DE010": {"type": LengthType.FIXED, "limit": 8, "parser": parseString, "unparser": unparseString},
    "DE011": {"type": LengthType.FIXED, "limit": 6, "parser": parseString, "unparser": unparseString},
    "DE012": {"type": LengthType.FIXED, "limit": 12, "parser": parseString, "unparser": unparseString},
    "DE013": {"type": LengthType.FIXED, "limit": 4, "parser": parseString, "unparser": unparseString},
    "DE014": {"type": LengthType.FIXED, "limit": 4, "parser": parseString, "unparser": unparseString},
    "DE015": {"type": LengthType.FIXED, "limit": 4, "parser": parseString, "unparser": unparseString},
    "DE016": {"type": LengthType.FIXED, "limit": 4, "parser": parseString, "unparser": unparseString},
    "DE017": {"type": LengthType.FIXED, "limit": 4, "parser": parseString, "unparser": unparseString},
    "DE018": {"type": LengthType.FIXED, "limit": 4, "parser": parseString, "unparser": unparseString},
    "DE019": {"type": LengthType.FIXED, "limit": 3, "parser": parseString, "unparser": unparseString},
    "DE020": {"type": LengthType.FIXED, "limit": 3, "parser": parseString, "unparser": unparseString},
    "DE021": {"type": LengthType.FIXED, "limit": 3, "parser": parseString, "unparser": unparseString},
    "DE022": {"type": LengthType.FIXED, "limit": 12, "parser": parseString, "unparser": unparseString},
    "DE023": {"type": LengthType.FIXED, "limit": 3, "parser": parseString, "unparser": unparseString},
    "DE024": {"type": LengthType.FIXED, "limit": 3, "parser": parseString, "unparser": unparseString},
    "DE025": {"type": LengthType.FIXED, "limit": 4, "parser": parseString, "unparser": unparseString},
    "DE026": {"type": LengthType.FIXED, "limit": 4, "parser": parseString, "unparser": unparseString},
    "DE027": {"type": LengthType.FIXED, "limit": 1, "parser": parseString, "unparser": unparseString},
    "DE028": {"type": LengthType.FIXED, "limit": 9, "parser": parseString, "unparser": unparseString},
    "DE029": {"type": LengthType.FIXED, "limit": 9, "parser": parseString, "unparser": unparseString},
    "DE030": {"type": LengthType.FIXED, "limit": 24, "parser": parseString, "unparser": unparseString},
    "DE031": {"type": LengthType.LLVAR, "limit": 23, "parser": parseString, "unparser": unparseString},
    "DE032": {"type": LengthType.LLVAR, "limit": 11, "parser": parseString, "unparser": unparseString},
    "DE033": {"type": LengthType.LLVAR, "limit": 11, "parser": parseString, "unparser": unparseString},
    "DE034": {"type": LengthType.LLVAR, "limit": 28, "parser": parseString, "unparser": unparseString},
    "DE035": {"type": LengthType.LLVAR, "limit": 37, "parser": parseString, "unparser": unparseString},
    "DE036": {"type": LengthType.LLLVAR, "limit": 104, "parser": parseString, "unparser": unparseString},
    "DE037": {"type": LengthType.FIXED, "limit": 12, "parser": parseString, "unparser": unparseString},
    "DE038": {"type": LengthType.FIXED, "limit": 6, "parser": parseString, "unparser": unparseString},
    "DE039": {"type": LengthType.FIXED, "limit": 2, "parser": parseString, "unparser": unparseString},
    "DE040": {"type": LengthType.FIXED, "limit": 3, "parser": parseString, "unparser": unparseString},
    "DE041": {"type": LengthType.FIXED, "limit": 8, "parser": parseString, "unparser": unparseString},
    "DE042": {"type": LengthType.FIXED, "limit": 15, "parser": parseString, "unparser": unparseString},
    "DE043": {"type": LengthType.LLVAR, "limit": 99, "parser": parseString, "unparser": unparseString},
    "DE044": {"type": LengthType.LLVAR, "limit": 25, "parser": parseString, "unparser": unparseString},
    "DE045": {"type": LengthType.LLVAR, "limit": 76, "parser": parseString, "unparser": unparseString},
    "DE046": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE047": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE048": {"type": LengthType.LLLVAR, "limit": 999, "parser": parsePds, "unparser": unparsePds},
    "DE049": {"type": LengthType.FIXED, "limit": 3, "parser": parseString, "unparser": unparseString},
    "DE050": {"type": LengthType.FIXED, "limit": 3, "parser": parseString, "unparser": unparseString},
    "DE051": {"type": LengthType.FIXED, "limit": 3, "parser": parseString, "unparser": unparseString},
    "DE052": {"type": LengthType.FIXED, "limit": 8, "parser": parseBytesToBin, "unparser": unparseBytesToBin},
    "DE053": {"type": LengthType.FIXED, "limit": 16, "parser": parseString, "unparser": unparseString},
    "DE054": {"type": LengthType.LLLVAR, "limit": 240, "parser": parseString, "unparser": unparseString},
    "DE055": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseBin, "unparser": unparseBin},
    "DE056": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE057": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE058": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE059": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE060": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE061": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE062": {"type": LengthType.LLLVAR, "limit": 999, "parser": parsePds, "unparser": unparsePds},
    "DE063": {"type": LengthType.LLLVAR, "limit": 16, "parser": parseString, "unparser": unparseString},
    "DE064": {"type": LengthType.FIXED, "limit": 8, "parser": parseBytesToBin, "unparser": unparseBytesToBin},
    "DE065": {"type": LengthType.FIXED, "limit": 8, "parser": parseBytesToBin, "unparser": unparseBytesToBin},
    "DE066": {"type": LengthType.FIXED, "limit": 1, "parser": parseString, "unparser": unparseString},
    "DE067": {"type": LengthType.FIXED, "limit": 2, "parser": parseString, "unparser": unparseString},
    "DE068": {"type": LengthType.FIXED, "limit": 3, "parser": parseString, "unparser": unparseString},
    "DE069": {"type": LengthType.FIXED, "limit": 3, "parser": parseString, "unparser": unparseString},
    "DE070": {"type": LengthType.FIXED, "limit": 3, "parser": parseString, "unparser": unparseString},
    "DE071": {"type": LengthType.FIXED, "limit": 8, "parser": parseString, "unparser": unparseString},
    "DE072": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE073": {"type": LengthType.FIXED, "limit": 6, "parser": parseString, "unparser": unparseString},
    "DE074": {"type": LengthType.FIXED, "limit": 10, "parser": parseString, "unparser": unparseString},
    "DE075": {"type": LengthType.FIXED, "limit": 10, "parser": parseString, "unparser": unparseString},
    "DE076": {"type": LengthType.FIXED, "limit": 10, "parser": parseString, "unparser": unparseString},
    "DE077": {"type": LengthType.FIXED, "limit": 10, "parser": parseString, "unparser": unparseString},
    "DE078": {"type": LengthType.FIXED, "limit": 10, "parser": parseString, "unparser": unparseString},
    "DE079": {"type": LengthType.FIXED, "limit": 10, "parser": parseString, "unparser": unparseString},
    "DE080": {"type": LengthType.FIXED, "limit": 10, "parser": parseString, "unparser": unparseString},
    "DE081": {"type": LengthType.FIXED, "limit": 10, "parser": parseString, "unparser": unparseString},
    "DE082": {"type": LengthType.FIXED, "limit": 12, "parser": parseString, "unparser": unparseString},
    "DE083": {"type": LengthType.FIXED, "limit": 12, "parser": parseString, "unparser": unparseString},
    "DE084": {"type": LengthType.FIXED, "limit": 12, "parser": parseString, "unparser": unparseString},
    "DE085": {"type": LengthType.FIXED, "limit": 12, "parser": parseString, "unparser": unparseString},
    "DE086": {"type": LengthType.FIXED, "limit": 16, "parser": parseString, "unparser": unparseString},
    "DE087": {"type": LengthType.FIXED, "limit": 16, "parser": parseString, "unparser": unparseString},
    "DE088": {"type": LengthType.FIXED, "limit": 16, "parser": parseString, "unparser": unparseString},
    "DE089": {"type": LengthType.FIXED, "limit": 16, "parser": parseString, "unparser": unparseString},
    "DE090": {"type": LengthType.FIXED, "limit": 42, "parser": parseString, "unparser": unparseString},
    "DE091": {"type": LengthType.FIXED, "limit": 1, "parser": parseString, "unparser": unparseString},
    "DE092": {"type": LengthType.FIXED, "limit": 2, "parser": parseString, "unparser": unparseString},
    "DE093": {"type": LengthType.LLVAR, "limit": 11, "parser": parseString, "unparser": unparseString},
    "DE094": {"type": LengthType.LLVAR, "limit": 11, "parser": parseString, "unparser": unparseString},
    "DE095": {"type": LengthType.LLVAR, "limit": 10, "parser": parseString, "unparser": unparseString},
    "DE096": {"type": LengthType.FIXED, "limit": 8, "parser": parseString, "unparser": unparseString},
    "DE097": {"type": LengthType.FIXED, "limit": 17, "parser": parseString, "unparser": unparseString},
    "DE098": {"type": LengthType.FIXED, "limit": 25, "parser": parseString, "unparser": unparseString},
    "DE099": {"type": LengthType.LLVAR, "limit": 11, "parser": parseString, "unparser": unparseString},
    "DE100": {"type": LengthType.LLVAR, "limit": 11, "parser": parseString, "unparser": unparseString},
    "DE101": {"type": LengthType.LLVAR, "limit": 17, "parser": parseString, "unparser": unparseString},
    "DE102": {"type": LengthType.LLVAR, "limit": 28, "parser": parseString, "unparser": unparseString},
    "DE103": {"type": LengthType.LLVAR, "limit": 28, "parser": parseString, "unparser": unparseString},
    "DE104": {"type": LengthType.LLLVAR, "limit": 100, "parser": parseString, "unparser": unparseString},
    "DE105": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE106": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE107": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE108": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE109": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE110": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE111": {"type": LengthType.LLLVAR, "limit": 12, "parser": parseString, "unparser": unparseString},
    "DE112": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE113": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE114": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE115": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE116": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE117": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE118": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE119": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE120": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE121": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE122": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE123": {"type": LengthType.LLLVAR, "limit": 999, "parser": parsePds, "unparser": unparsePds},
    "DE124": {"type": LengthType.LLLVAR, "limit": 999, "parser": parsePds, "unparser": unparsePds},
    "DE125": {"type": LengthType.LLLVAR, "limit": 999, "parser": parsePds, "unparser": unparsePds},
    "DE126": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE127": {"type": LengthType.LLLVAR, "limit": 999, "parser": parseString, "unparser": unparseString},
    "DE128": {"type": LengthType.FIXED, "limit": 8, "parser": parseBytesToBin, "unparser": unparseBytesToBin},
}}

